DeserializeDriver

Struct DeserializeDriver 

pub struct DeserializeDriver<'a> { /* private fields */ }
The driver allows emitting deserialization events into a Deserialize.

This is a convenient way to safely drive a Sink of a Deserialize without using the runtime stack. As rust lifetimes make what this type does internally impossible with safe code, this is a safe abstractiont that hides the unsafety internally.

Implementations

Source

impl<'a> DeserializeDriver<'a>

pub fn new<T: Deserialize>(out: &'a mut Option<T>) -> DeserializeDriver<'a>

Creates a new deserializer driver.

pub fn from_sink(sink: SinkHandle<'_>) -> DeserializeDriver<'a>

Creates a new deserializer driver from a sink.

pub fn state(&self) -> &DeserializerState<'_>

Returns a borrowed reference to the current deserializer state.

pub fn emit<'e, E: Into<Event<'e>>>(&mut self, event: E) -> Result<(), Error>

Emits an event into the driver.

Panics

The driver keeps an internal state and emitting events when they are not expected will cause the driver to panic.