#[non_exhaustive]pub enum Order {
Natural,
Arbitrary,
Sorted,
Significant,
}Expand description
How significant the order of the elements of a container is.
The default (Order::Natural) means the natural semantics of the
container: the order of sequences is significant, the order of maps is
not but the emitted order is kept. Only deviations are marked.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Natural
The natural semantics of the container.
Arbitrary
The order is not significant and the elements are emitted in an
arbitrary order that can change between runs (HashMap, HashSet).
Sorted
The order is not significant and the elements are sorted
(BTreeMap, BTreeSet).
Significant
The order is significant, also for maps.