SerializeHandle

Enum SerializeHandle 

pub enum SerializeHandle<'a> {
    Borrowed(&'a dyn Serialize),
    Owned(Box<dyn Serialize + 'a>),
}
A handle to a Serialize type.

During serialization it common to be in a situation where one needs to return locally constructed Serialize. This is where SerializeHandle comes in. In cases where the Serialize cannot be borrowed it can be boxed up inside the handle.

The equivalent for deserialization is the SinkHandle.

Variants



Borrowed(&'a dyn Serialize)

A borrowed reference to a Serialize.



Owned(Box<dyn Serialize + 'a>)

A boxed up Serialize.

Implementations

Source

impl<'a> SerializeHandle<'a>

pub fn to<S: Serialize + 'a>(val: &'a S) -> SerializeHandle<'a>

Create a borrowed handle to a Serialize.

pub fn boxed<S: Serialize + 'a>(val: S) -> SerializeHandle<'a>

Create an owned handle to a heap allocated Serialize.