pub struct SerializerState<'a> { /* private fields */ }Expand description
The current state of the serializer.
During serializer the SerializerState acts as a communciation device between
the serializable types as the serializer.
Implementations
Sourceimpl<'a> SerializerState<'a>
impl<'a> SerializerState<'a>
Sourcepub fn get_mut<T: Default + Debug + 'static>(&self) -> RefMut<'_, T>
pub fn get_mut<T: Default + Debug + 'static>(&self) -> RefMut<'_, T>
Returns a mutable extension value.
Sourcepub fn top_descriptor(&self) -> Option<&dyn Descriptor>
pub fn top_descriptor(&self) -> Option<&dyn Descriptor>
Returns the topmost descriptor.
This descriptor always points to a container as the descriptor of a value itself will always be passed to the callback explicitly.